<?php

/**
 * Action : associer un album à un objet éditorial
 *
 * @plugin     Albums
 * @copyright  2014
 * @author     Tetue, Charles Razack
 * @licence    GPL
 * @package    SPIP\Albums\Action
 */

// Sécurité
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Associer un album à un objet éditorial
 *
 * @example
 *     ```
 *     #URL_ACTION_AUTEUR{associer_album, #ID_ALBUM/#OBJET/#ID_OBJET, #SELF}
 *     ```
 *
 * @param string|null $arg
 *     Arguments séparés par un slash `/`
 *     sous la forme `id_album/objet/id_objet`
 *
 *     - id_album : identifiant de l'album
 *     - objet    : type d'objet à associer
 *     - id_objet : identifiant de l'objet à associer
 * @return bool
 */
function action_associer_album_dist($arg = null) {

	// Si $arg n'est pas donné directement, le récupérer via _POST ou _GET
	if (is_null($arg)) {
		$securiser_action = charger_fonction('securiser_action', 'inc');
		$arg = $securiser_action();
	}
	$ok = false;

	// Éviter les notices si arg mal formaté
	if (substr_count($arg, '/') === 2) {
		[$id_album, $objet, $id_objet] = explode('/', $arg);
		$id_album = (int) $id_album;
		$id_objet = (int) $id_objet; // peut être négatif
	
		// Il faut avoir le droit
		if (
			$id_album
			and $objet
			and autoriser('associer', 'album', $id_album, '', ['objet' => $objet, 'id_objet' => $id_objet])
		) {
			include_spip('action/editer_liens');
			// objet_associer retourne le nombre de liens traités en cas de succès, sinon false
			$associer = objet_associer(['album' => $id_album], [$objet => $id_objet]);
			$ok = ($associer > 0 ? true : false);
		}
	}

	if (!$ok) {
		spip_log("associer_album : erreur, ou action pas autorisée, ou arg pas compris : $arg", 'albums');
	}

	return $ok;
}
